@@ -6,14 +6,14 @@ import datetime
 from dateutil.relativedelta import relativedelta
 from dateutil.rrule import YEARLY, MONTHLY, DAILY, HOURLY, MINUTELY, SECONDLY
 from django.http import HttpResponse
-from matplotlib.ticker import MaxNLocator
 from matplotlib.backends.backend_agg import FigureCanvasAgg as FigureCanvas
-from matplotlib.dates import AutoDateLocator
 from matplotlib.dates import AutoDateFormatter
+from matplotlib.dates import AutoDateLocator
 from matplotlib.dates import RRuleLocator
 from matplotlib.dates import date2num
 from matplotlib.dates import rrulewrapper
 from matplotlib.figure import Figure
+from matplotlib.ticker import MaxNLocator
 
 from lizard_map.matplotlib_settings import FONT_SIZE
 
@@ -131,9 +131,9 @@ class Graph(object):
         self.today = today
 
         self.figure = Figure()
-        if width is None:
+        if width is None or not width:
             width = 380.0
-        if height is None:
+        if height is None or not height:
             height = 250.0
         self.width = float(width)
         self.height = float(height)
