@@ -1,7 +1,7 @@
 // jslint configuration
 /*jslint browser: true */
 /*global $, OpenLayers, window, updateLayer, stretchOneSidebarBox,
-reloadGraphs, fillSidebar */
+reloadGraphs, fillSidebar, show_popup */
 
 function setUpWorkspaceAcceptable() {
     // Set up draggability for current and future items.
@@ -130,35 +130,20 @@ function setUpEmptyTempInteraction() {
 }
 
 
-function loadSizedImages() {
-    var height, width;
-    // height = verticalItemHeight;
-    height = '';
-    width = mainContentWidth;
-    $('a.replace-with-image').each(
-        function (index) {
-            var url, timestamp;
-            $(this).hide();
-            url = $(this).attr('href');
-            $('~ img', this).remove();
-            timestamp = new Date().getTime();  // No cached images.
-            // dit doet het niet goed bij urls met json {" ... "}
-            $(this).after('<img src="' + url + '?width=' + width + '&height=' +
-                          height + '&random=' + timestamp + '" />');
-        }
-    );    
-}
+// Commented out: lizard-ui now has generic support for it (see the
+// in-browser documentation).
+// function loadSizedImages() {
 
 
 function popup_click_handler(x, y, map) {
-    var extent, radius;
+    var extent, radius, url;
     extent = map.getExtent();
     radius = Math.abs(extent.top - extent.bottom) / 50;  // experimental, seems to work good
     $("#map_OpenLayers_ViewPort").css("cursor", "progress");
     url = $(".workspace").attr("data-url-lizard-map-search-coordinates");
     if (url !== undefined) {
         $.getJSON(
-            url, 
+            url,
             { x: x, y: y, radius: radius },
             function (data) {
                 $("#map_OpenLayers_ViewPort").css("cursor", "default");
@@ -180,5 +165,4 @@ $(document).ready(function () {
     $(".workspace").workspaceInteraction();
     // $(".add-snippet").snippetInteraction(); // als het met live werkt kan het hier
     // $("a.lizard-map-link").lizardMapLink();
-    loadSizedImages();
 });
