@@ -23,6 +23,8 @@ urlpatterns = patterns(
         name="lizard_map_workspace_item_add"),
     url(r'^workspace/(?P<workspace_id>\d+)/',
         'lizard_map.views.workspace',
+        {'javascript_click_handler': 'popup_click_handler',  # TODO: does not work outside krw yet
+         },
         name="lizard_map_workspace"),
 
     # Date range
@@ -84,6 +86,12 @@ urlpatterns = patterns(
     url(r'^workspaceitem/edit/',
         'lizard_map.views.workspace_item_edit',
         name="lizard_map_workspace_item_edit"),
+
+    # Search stuff.
+    url(r'^search_coordinates/',
+        'lizard_map.views.search_coordinates',
+        name="lizard_map.search_coordinates"),
+
     )
 
 
